# -*- coding: UTF-8 -*-
'''
@学习网站      ：https://www.python-office.com
@读者群     ：http://www.python4office.cn/wechat-group/
@作者  ：B站/抖音/微博/小红书/公众号，都叫：程序员晚枫，微信：python-office
@代码日期    ：2024/1/20 0:17 
@本段代码的视频说明     ：
'''
import os
import unittest

from poai.api.chat import *


class TestTools(unittest.TestCase):
    def test_ali(self):
        # 替换为你的API密钥
        api_key = os.getenv("TY_KEY")  # 此处填入你的api-key
        print(ali(api_key, prompt='你好'))

    def test_zhipu(self):
        # 替换为你的API密钥
        api_key = ''  # 此处填入你的api-key
        print(zhipu(api_key))

    def test_deepseek(self):
        print(deepseek(api_key='sk-pRdhASKn0wm5i7DjkdDfj5ENbRcpsqGrtV7hdFZZ6laV5aMk', content='你好'))



# -*- coding: UTF-8 -*-
'''
@学习网站      ：https://www.python-office.com
@读者群     ：http://www.python4office.cn/wechat-group/
@作者  ：B站/抖音/微博/小红书/公众号，都叫：程序员晚枫，微信：python-office
@代码日期    ：2024/3/1 23:54 
@本段代码的视频说明     ：
'''
from zhipuai import ZhipuAI


def get_response(api_key, prompt='你好，请介绍一下python-office', model="glm-4"):
    client = ZhipuAI(api_key=api_key)  # 填写您自己的APIKey
    response = client.chat.completions.create(
        model=model,  # 填写需要调用的模型名称
        messages=[
            {"role": "user", "content": prompt},
        ],
    )
    return response.choices[0].message.content



# -*- coding: UTF-8 -*-
'''
@Author  ：程序员晚枫，B站/抖音/微博/小红书/公众号
@WeChat     ：CoderWanFeng
@Blog      ：www.python-office.com
@Date    ：2023/2/8 23:39
@Description     ：
'''
from poai.api import chatgpt
from poai.api import aiart
from poai.api import chat
# from poai.lib.Const import SPLIT_LINE
#
# print(SPLIT_LINE)
# print('【poai库】，功能持续更新中')
# print('使用有问题 or 提交你的功能需求 or 参与项目开发')
# print('1、请+【项目交流群】：http://www.python4office.cn/wechat-group/')
# print('2、本开源项目的【代码仓库】：https://github.com/CoderWanFeng/poai')
# print('3、免费的微信机器人：https://mp.weixin.qq.com/s/9aspEHdCiAdXK17AvHlu9Q')
# print(SPLIT_LINE)


# -*- coding: UTF-8 -*-
'''
@学习网站      ：https://www.python-office.com
@读者群     ：http://www.python4office.cn/wechat-group/
@作者  ：B站/抖音/微博/小红书/公众号，都叫：程序员晚枫，微信：python-office
@代码日期    ：2024/1/18 23:27 
@本段代码的视频说明     ：
'''

from poai.core.DeepSeek import get_response_from_deepseek_in_tx
from poai.core.TongYi import Tongyi
from poai.core.ZhiPu import get_response


def ali(api_key: str, prompt: str):
    """
    调用大模型
    :param api_key:
    :param prompt:
    :return:
    """
    ty = Tongyi(api_key=api_key)
    return ty.qianwen_max(prompt)


def zhipu(api_key, prompt='你好，请介绍一下python-office', model="glm-4"):
    # https://open.bigmodel.cn/dev/api#overview
    return get_response(api_key, prompt, model)


def deepseek(api_key, content, origin=False, tx=True):
    if tx:
        return get_response_from_deepseek_in_tx(api_key, content)



# -*- coding: UTF-8 -*-
'''
@作者  ：B站/抖音/微博/小红书/公众号，都叫：程序员晚枫，微信：python-office
@读者群     ：http://www.python4office.cn/wechat-group/
@学习网站      ：https://www.python-office.com
@代码日期    ：2023/12/5 21:35 
@本段代码的视频说明     ：
'''
from poai.core.AIArt import get_text2image_result


def text2image(id, key, prompt: str, output: str = r'./text2image.jpg'):
    """
    1行代码，生成AI绘画
    :param id: 腾讯云的id，开通方式：https://curl.qcloud.com/gyWD7glH
    :param key: 腾讯云的key，开通方式：https://curl.qcloud.com/gyWD7glH
    :param prompt: 关于图片的描述文本，将根据输入的文本智能生成与之相关的图像。建议详细描述画面主体、细节、场景等，文本描述越丰富，生成效果越精美。
                    不能为空，推荐使用中文。最多可传256个 utf-8 字符。
    :param output: 输出图片的位置和名称。
    :return:
    """
    get_text2image_result(id, key, prompt, output)



# -*- coding: UTF-8 -*-
'''
@作者  ：B站/抖音/微博/小红书/公众号，都叫：程序员晚枫，微信：python-office
@读者群     ：http://www.python4office.cn/wechat-group/
@学习网站      ：https://www.python-office.com
@代码日期    ：2023/12/5 21:35 
@本段代码的视频说明     ：
'''

import base64
import json
from io import BytesIO
from pathlib import Path
import os
from PIL import Image
from tencentcloud.aiart.v20221229 import aiart_client, models
from tencentcloud.common import credential
from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tencentcloud.common.profile.client_profile import ClientProfile
from tencentcloud.common.profile.http_profile import HttpProfile


def get_text2image_result(id, key, prompt, output):
    # 实例化一个认证对象，入参需要传入腾讯云账户 SecretId 和 SecretKey，此处还需注意密钥对的保密
    # 代码泄露可能会导致 SecretId 和 SecretKey 泄露，并威胁账号下所有资源的安全性。以下代码示例仅供参考，建议采用更安全的方式来使用密钥，请参见：https://cloud.tencent.com/document/product/127
    try:
        # 实例化一个认证对象，入参需要传入腾讯云账户 SecretId 和 SecretKey，此处还需注意密钥对的保密
        # 代码泄露可能会导致 SecretId 和 SecretKey 泄露，并威胁账号下所有资源的安全性。以下代码示例仅供参考，建议采用更安全的方式来使用密钥，请参见：https://cloud.tencent.com/document/product/1278/85305
        # 密钥可前往官网控制台 https://console.cloud.tencent.com/cam/capi 进行获取

        cred = credential.Credential(id, key)
        # 实例化一个http选项，可选的，没有特殊需求可以跳过
        httpProfile = HttpProfile()
        httpProfile.endpoint = "aiart.tencentcloudapi.com"

        # 实例化一个client选项，可选的，没有特殊需求可以跳过
        clientProfile = ClientProfile()
        clientProfile.httpProfile = httpProfile
        # 实例化要请求产品的client对象,clientProfile是可选的
        client = aiart_client.AiartClient(cred, "ap-shanghai", clientProfile)

        # 实例化一个请求对象,每个接口都会对应一个request对象
        req = models.TextToImageRequest()
        params = {
            "Prompt": prompt,
        }
        req.from_json_string(json.dumps(params))

        # 返回的resp是一个TextToImageResponse的实例，与请求对象对应
        resp = client.TextToImage(req)
        # 输出json格式的字符串回包
        # print(resp)
        res_json = json.loads(str(resp))

        img_data = base64.b64decode(res_json["ResultImage"])  # 解码时只要内容部分
        image = Image.open(BytesIO(img_data))
        output_path = Path(output).absolute().parent
        if not output_path.exists():
            os.makedirs(str(output_path))
        image.save(output)
    except TencentCloudSDKException as err:
        print(err)



# -*- coding: UTF-8 -*-
'''
@学习网站      ：https://www.python-office.com
@读者群     ：http://www.python4office.cn/wechat-group/
@作者  ：B站/抖音/微博/小红书/公众号，都叫：程序员晚枫，微信：python-office
@代码日期    ：2024/1/18 0:26 
@本段代码的视频说明     ：
'''

import json

import requests


class Tongyi:
    def __init__(self, api_key, model_type='qwen-max'):
        """
        初始化函数。

        参数:
            api_key (str): API密钥，开通方式：https://help.aliyun.com/zh/dashscope/developer-reference/activate-dashscope-and-create-an-api-key?spm=a2c4g.11186623.0.0.72571c83RabAau
            model_type (str, 可选): 模型类型，默认为'qwen-max'。
        """

        self.api_key = api_key
        self.model_type = model_type
        self.url = 'https://dashscope.aliyuncs.com/api/v1/services/aigc/text-generation/generation'

    def qianwen_max(self, prompt: str) -> str:

        # API的URL

        # 请求头
        headers = {
            'Authorization': f'Bearer {self.api_key}',
            'Content-Type': 'application/json'
        }

        # 请求体
        data = {
            "model": self.model_type,
            "input": {
                "prompt": prompt
            },
            "parameters": {}
        }

        # 将字典转换为JSON字符串
        data_json = json.dumps(data)

        # 发送POST请求
        response = requests.post(self.url, headers=headers, data=data_json)

        # 检查响应状态码
        if response.status_code == 200:
            # 解析响应内容
            response_data = response.json()
            return response_data['output']['text']
        else:
            # print(f'Error: {response.status_code}')
            return response.status_code, response.text



# -*- coding: UTF-8 -*-
'''
@学习网站      ：https://www.python-office.com
@读者群     ：http://www.python4office.cn/wechat-group/
@作者  ：B站/抖音/微博/小红书/公众号，都叫：程序员晚枫，微信：python-office
@代码日期    ：2025/2/11 20:39 
@本段代码的视频说明     ：
'''

from openai import OpenAI


def get_response_from_deepseek_in_tx(api_key, content):
    # 构造 client
    client = OpenAI(
        api_key=api_key,  # 知识引擎原子能力 APIKey
        base_url="https://api.lkeap.cloud.tencent.com/v1",
    )
    # 流式
    s_value = False
    # 请求
    chat_completion = client.chat.completions.create(
        model="deepseek-r1",
        messages=[
            {
                "role": "user",
                "content": content,
            }
        ],
        stream=s_value,
    )
    if s_value:
        for chunk in chat_completion:
            # 打印思维链内容
            if hasattr(chunk.choices[0].delta, 'reasoning_content'):
                pass
                # print(f"{chunk.choices[0].delta.reasoning_content}", end="")
            # 打印模型最终返回的content
            if hasattr(chunk.choices[0].delta, 'content'):
                if chunk.choices[0].delta.content != None and len(chunk.choices[0].delta.content) != 0:
                    print(chunk.choices[0].delta.content, end="")
    else:
        result = chat_completion.choices[0].message.content
    return result


if __name__ == '__main__':
    get_response_from_deepseek_in_tx("sk-pRdhASKn0wm5i7DjkdDfj5ENbRcpsqGrtV7hdFZZ6laV5aMk", "你好")
